"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clunk = exports.parseArgs = void 0;
var Flag;
(function (Flag) {
    Flag[Flag["SHORT"] = 0] = "SHORT";
    Flag[Flag["LONG"] = 1] = "LONG";
})(Flag || (Flag = {}));
function whatFlag(text = '') {
    const characters = Array.from(text);
    const DASH = '-';
    const isSingleDash = characters[0] === DASH;
    const isDoubleDash = characters[1] === DASH;
    return isDoubleDash ? Flag.LONG : isSingleDash ? Flag.SHORT : null;
}
function removeDashes(text) {
    return text.replace(/-/g, '');
}
function getValue(text) {
    return text && whatFlag(text) === null
        ? text === 'false'
            ? false
            : text === 'true'
                ? true
                : isNaN(Number(text || ''))
                    ? text
                    : Number(text)
        : true;
}
function parseArgs(argv) {
    const hash = {};
    const [, , ...rest] = argv;
    for (let i = 0; i < rest.length; i++) {
        const text = rest[i];
        const nextText = rest[i + 1];
        const flagKind = whatFlag(text);
        if (flagKind === Flag.SHORT) {
            // Handle multiple short combined keys
            const keys = Array.from(removeDashes(text).toLowerCase());
            keys.forEach((key, i) => {
                // The last one should get the text argument the first ones should be booleans
                hash[key] = keys.length - 1 === i ? getValue(nextText) : true;
            });
        }
        else if (flagKind === Flag.LONG) {
            const key = removeDashes(text).toLowerCase();
            hash[key] = getValue(nextText);
        }
        else {
            const previousFlag = whatFlag(rest[i - 1]);
            if (i === 0) {
                hash.prefix = text;
            }
            else if (previousFlag === null && rest.length - 1 === i) {
                hash.suffix = text;
            }
        }
    }
    return hash;
}
exports.parseArgs = parseArgs;
function clunk() {
    return parseArgs(process.argv);
}
exports.clunk = clunk;
//# sourceMappingURL=index.js.map