"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = __importDefault(require("ava"));
const index_1 = require("./index");
const defaultArgs = ['.../node_modules/.bin/ts-node', '.../clunk/src/index'];
const testCases = [
    {
        name: "works don't it?",
        argv: [...defaultArgs, '--cool', 'beans', '-DE', 'nice'],
        expected: {
            cool: 'beans',
            d: true,
            e: 'nice',
        },
    },
    {
        name: 'long flags can be booleans',
        argv: [...defaultArgs, '--test', '---test2'],
        expected: {
            test: true,
            test2: true,
        },
    },
    {
        name: 'explicit booleans',
        argv: [...defaultArgs, '--nice', 'false', '-o', 'false', '-b', 'true'],
        expected: {
            nice: false,
            o: false,
            b: true,
        },
    },
    {
        name: 'support numbers',
        argv: [...defaultArgs, '--number1', '42', '-a', '10'],
        expected: {
            number1: 42,
            a: 10,
        },
    },
    {
        name: 'handles prefix suffix',
        argv: [...defaultArgs, 'command', '-abc', 'foo', '.'],
        expected: {
            prefix: 'command',
            a: true,
            b: true,
            c: 'foo',
            suffix: '.',
        },
    },
];
function getName(name, [, , ...argv]) {
    return `${name} | ${argv.join(' ')}`;
}
testCases.forEach(({ name, argv, expected }) => {
    ava_1.default(getName(name, argv), (t) => {
        const clunk = index_1.parseArgs(argv);
        t.deepEqual(clunk, expected);
    });
});
//# sourceMappingURL=index.test.js.map